@@ -2,12 +2,14 @@
 *
 *   raylib [audio] example - Raw audio streaming
 *
-*   This example has been created using raylib 1.6 (www.raylib.com)
-*   raylib is licensed under an unmodified zlib/libpng license (View raylib.h for details)
+*   Example originally created with raylib 1.6, last time updated with raylib 4.2
 *
 *   Example created by Ramon Santamaria (@raysan5) and reviewed by James Hofmann (@triplefox)
 *
-*   Copyright (c) 2015-2019 Ramon Santamaria (@raysan5) and James Hofmann (@triplefox)
+*   Example licensed under an unmodified zlib/libpng license, which is an OSI-certified,
+*   BSD-like license that allows static linking with closed source software
+*
+*   Copyright (c) 2015-2022 Ramon Santamaria (@raysan5) and James Hofmann (@triplefox)
 *
 ********************************************************************************************/
 
@@ -20,6 +22,38 @@
 #define MAX_SAMPLES               512
 #define MAX_SAMPLES_PER_UPDATE   4096
 
+// Cycles per second (hz)
+float frequency = 440.0f;
+
+// Audio frequency, for smoothing
+float audioFrequency = 440.0f;
+
+// Previous value, used to test if sine needs to be rewritten, and to smoothly modulate frequency
+float oldFrequency = 1.0f;
+
+// Index for audio rendering
+float sineIdx = 0.0f;
+
+// Audio input processing callback
+void AudioInputCallback(void *buffer, unsigned int frames)
+{
+    audioFrequency = frequency + (audioFrequency - frequency)*0.95f;
+    audioFrequency += 1.0f;
+    audioFrequency -= 1.0f;
+    float incr = audioFrequency/44100.0f;
+    short *d = (short *)buffer;
+
+    for (int i = 0; i < frames; i++)
+    {
+        d[i] = (short)(32000.0f*sinf(2*PI*sineIdx));
+        sineIdx += incr;
+        if (sineIdx > 1.0f) sineIdx -= 1.0f;
+    }
+}
+
+//------------------------------------------------------------------------------------
+// Program main entry point
+//------------------------------------------------------------------------------------
 int main(void)
 {
     // Initialization
@@ -33,9 +67,11 @@ int main(void)
 
     SetAudioStreamBufferSizeDefault(MAX_SAMPLES_PER_UPDATE);
 
-    // Init raw audio stream (sample rate: 22050, sample size: 16bit-short, channels: 1-mono)
+    // Init raw audio stream (sample rate: 44100, sample size: 16bit-short, channels: 1-mono)
     AudioStream stream = LoadAudioStream(44100, 16, 1);
 
+    SetAudioStreamCallback(stream, AudioInputCallback);
+
     // Buffer for the single cycle waveform we are synthesizing
     short *data = (short *)malloc(sizeof(short)*MAX_SAMPLES);
 
@@ -47,6 +83,7 @@ int main(void)
     // Position read in to determine next frequency
     Vector2 mousePosition = { -100.0f, -100.0f };
 
+    /*
     // Cycles per second (hz)
     float frequency = 440.0f;
 
@@ -55,6 +92,7 @@ int main(void)
 
     // Cursor to read and copy the samples of the sine wave buffer
     int readCursor = 0;
+    */
 
     // Computed size in samples of the sine wave
     int waveLength = 1;
@@ -77,29 +115,38 @@ int main(void)
         {
             float fp = (float)(mousePosition.y);
             frequency = 40.0f + (float)(fp);
+
+            float pan = (float)(mousePosition.x) / (float)screenWidth;
+            SetAudioStreamPan(stream, pan);
         }
 
-        // Rewrite the sine wave.
+        // Rewrite the sine wave
         // Compute two cycles to allow the buffer padding, simplifying any modulation, resampling, etc.
         if (frequency != oldFrequency)
         {
             // Compute wavelength. Limit size in both directions.
-            int oldWavelength = waveLength;
+            //int oldWavelength = waveLength;
             waveLength = (int)(22050/frequency);
             if (waveLength > MAX_SAMPLES/2) waveLength = MAX_SAMPLES/2;
             if (waveLength < 1) waveLength = 1;
 
-            // Write sine wave.
+            // Write sine wave
             for (int i = 0; i < waveLength*2; i++)
             {
                 data[i] = (short)(sinf(((2*PI*(float)i/waveLength)))*32000);
             }
+            // Make sure the rest of the line is flat
+            for (int j = waveLength*2; j < MAX_SAMPLES; j++)
+            {
+                data[j] = (short)0;
+            }
 
             // Scale read cursor's position to minimize transition artifacts
-            readCursor = (int)(readCursor * ((float)waveLength / (float)oldWavelength));
+            //readCursor = (int)(readCursor * ((float)waveLength / (float)oldWavelength));
             oldFrequency = frequency;
         }
 
+        /*
         // Refill audio stream if required
         if (IsAudioStreamProcessed(stream))
         {
@@ -128,6 +175,7 @@ int main(void)
             // Copy finished frame to audio stream
             UpdateAudioStream(stream, writeBuf, MAX_SAMPLES_PER_UPDATE);
         }
+        */
         //----------------------------------------------------------------------------------
 
         // Draw
@@ -137,7 +185,7 @@ int main(void)
             ClearBackground(RAYWHITE);
 
             DrawText(TextFormat("sine frequency: %i",(int)frequency), GetScreenWidth() - 220, 10, 20, RED);
-            DrawText("click mouse button to change frequency", 10, 10, 20, DARKGRAY);
+            DrawText("click mouse button to change frequency or pan", 10, 10, 20, DARKGRAY);
 
             // Draw the current buffer state proportionate to the screen
             for (int i = 0; i < screenWidth; i++)
