@@ -2,20 +2,25 @@
 *
 *   raylib [shapes] example - draw ring (with gui options)
 *
-*   This example has been created using raylib 2.5 (www.raylib.com)
-*   raylib is licensed under an unmodified zlib/libpng license (View raylib.h for details)
+*   Example originally created with raylib 2.5, last time updated with raylib 2.5
 *
 *   Example contributed by Vlad Adrian (@demizdor) and reviewed by Ramon Santamaria (@raysan5)
 *
-*   Copyright (c) 2018 Vlad Adrian (@demizdor) and Ramon Santamaria (@raysan5)
+*   Example licensed under an unmodified zlib/libpng license, which is an OSI-certified,
+*   BSD-like license that allows static linking with closed source software
+*
+*   Copyright (c) 2018-2022 Vlad Adrian (@demizdor) and Ramon Santamaria (@raysan5)
 *
 ********************************************************************************************/
 
 #include <raylib.h>
 
 #define RAYGUI_IMPLEMENTATION
-#include "extras/raygui.h"                 // Required for GUI controls
+#include "raygui.h"                 // Required for GUI controls
 
+//------------------------------------------------------------------------------------
+// Program main entry point
+//------------------------------------------------------------------------------------
 int main(void)
 {
     // Initialization
@@ -33,7 +38,6 @@ int main(void)
     float startAngle = 0.0f;
     float endAngle = 360.0f;
     int segments = 0;
-    int minSegments = 4;
 
     bool drawRing = true;
     bool drawRingLines = false;
@@ -78,7 +82,7 @@ int main(void)
             drawCircleLines = GuiCheckBox((Rectangle){ 600, 380, 20, 20 }, "Draw CircleLines", drawCircleLines);
             //------------------------------------------------------------------------------
 
-            int minSegments = (int)ceilf((endAngle - startAngle) / 90);
+            int minSegments = (int)ceilf((endAngle - startAngle)/90);
             DrawText(TextFormat("MODE: %s", (segments >= minSegments)? "MANUAL" : "AUTO"), 600, 270, 10, (segments >= minSegments)? MAROON : DARKGRAY);
 
             DrawFPS(10, 10);
